@@ -128,84 +128,6 @@ weave_geom_defaults <- function(
   ggplot2::update_geom_defaults("pointrange", ggplot2::aes(colour = !!colour, fill = !!colour, linewidth = 0.66, size = 0.2)) # 1.5 / 7.5
 }
 
-#' Set the font geom defaults
-#'
-#' @description Update the "text" and "label" geom defaults. Note all other text is controlled by the theme.
-#'
-#' @param ... Provided to require argument naming, support trailing commas etc.
-#' @param colour A hex code.
-#' @param fill A hex code.
-#' @param size A size.
-#' @param family A family.
-#'
-#' @export
-#'
-#' @examples
-#' library(ggplot2)
-#' library(dplyr)
-#' library(palmerpenguins)
-#'
-#' set_blanket(theme = dark_mode_r())
-#' weave_font_defaults(colour = darkness[1])
-#' weave_reference_defaults(colour = darkness[1])
-#'
-#' penguins |>
-#'   gg_point(
-#'     x = flipper_length_mm,
-#'     y = body_mass_g,
-#'     x_breaks_n = 4,
-#'   ) +
-#'   geom_vline(xintercept = 200) +
-#'   annotate("text", x = I(0.25), y = I(0.75), label = "Here")
-#'
-weave_font_defaults <- function(
-    ...,
-    colour = "#121B24FF",
-    fill = "#FFFFFFFF",
-    size = 11 / 2.835052,
-    family = "") {
-
-  ggplot2::update_geom_defaults("text", ggplot2::aes(colour = !!colour, size = !!size, family = !!family))
-  ggplot2::update_geom_defaults("label", ggplot2::aes(colour = !!colour, fill = !!fill, size = !!size, family = !!family))
-}
-
-#' Set reference-line geom defaults
-#'
-#' @description Update the "abline", "hline" and "vline" geom defaults.
-#'
-#' @param ... Provided to require argument naming, support trailing commas etc.
-#' @param colour A hex code.
-#' @param linewidth A linewidth.
-#'
-#' @export
-#'
-#' @examples
-#' library(ggplot2)
-#' library(dplyr)
-#' library(palmerpenguins)
-#'
-#' set_blanket(theme = dark_mode_r())
-#' weave_font_defaults(colour = darkness[1])
-#' weave_reference_defaults(colour = darkness[1])
-#'
-#' penguins |>
-#'   gg_point(
-#'     x = flipper_length_mm,
-#'     y = body_mass_g,
-#'     x_breaks_n = 4,
-#'   ) +
-#'   geom_vline(xintercept = 200) +
-#'   annotate("text", x = I(0.25), y = I(0.75), label = "Here")
-#'
-weave_reference_defaults <- function(
-    ...,
-    colour = "#121B24FF",
-    linewidth = 0.25) {
-  ggplot2::update_geom_defaults("abline", ggplot2::aes(colour = !!colour, linewidth = !!linewidth))
-  ggplot2::update_geom_defaults("hline", ggplot2::aes(colour = !!colour, linewidth = !!linewidth))
-  ggplot2::update_geom_defaults("vline", ggplot2::aes(colour = !!colour, linewidth = !!linewidth))
-}
-
 #' Set colour (and fill) palettes
 #'
 #' @param ... Provided to require argument naming, support trailing commas etc.
