@@ -18,7 +18,7 @@ test_that(test_name, {
       facet = sex,
       facet2 = island,
       mapping = aes(alpha = species, shape = species),
-      mode = light_mode_r()
+      theme = light_mode_r()
     ) +
     scale_alpha_manual(values = c(1, 1, 0.33))
 
@@ -37,7 +37,7 @@ test_that(test_name, {
       facet = sex,
       facet2 = island,
       mapping = aes(alpha = species, shape = species),
-      mode = light_mode_t()
+      theme = light_mode_t()
     ) +
     scale_alpha_manual(values = c(1, 1, 0.33))
 
@@ -56,7 +56,7 @@ test_that(test_name, {
       facet = sex,
       facet2 = island,
       mapping = aes(alpha = species, shape = species),
-      mode = light_mode_b()
+      theme = light_mode_b()
     ) +
     scale_alpha_manual(values = c(1, 1, 0.33))
 
@@ -76,7 +76,7 @@ test_that(test_name, {
       facet = sex,
       facet2 = island,
       mapping = aes(alpha = species, shape = species),
-      mode = dark_mode_r()
+      theme = dark_mode_r()
     ) +
     scale_alpha_manual(values = c(1, 1, 0.33))
 
