@@ -16,8 +16,8 @@ test_that(test_name, {
     theme_axis_ticks_rm = FALSE,
     theme_panel_grid_rm = FALSE
   )
-  weave_font_defaults()
-  weave_reference_defaults()
+  set_font_defaults()
+  set_reference_defaults()
 
   p <- penguins |>
     mutate(across(sex, \(x) stringr::str_to_sentence(x))) |>
@@ -41,9 +41,9 @@ test_that(test_name, {
     colour = red,
   )
 
-  weave_font_defaults(colour = teal)
+  set_font_defaults(colour = teal)
 
-  weave_reference_defaults(colour = teal)
+  set_reference_defaults(colour = teal)
 
   p <- penguins |>
     mutate(across(sex, \(x) stringr::str_to_sentence(x))) |>
@@ -66,9 +66,9 @@ set_blanket(
   col_palette_c = c(navy, purple, red, orange)
 )
 
-weave_font_defaults(colour = "red", size = 15 / 2.83505)
+set_font_defaults(colour = "red", size = 15 / 2.83505)
 
-weave_reference_defaults(colour = "red", linewidth = 5)
+set_reference_defaults(colour = "red", linewidth = 5)
 
 ###
 test_name <- "3"
